get_permutation_weights: Estimate permutation weights B times and average the results

Description Usage

View source: R/estimator_permuation.R

Description

Estimate permutation weights B times and average the results

Usage

1
2
3
4
5
6
7
8
9
get_permutation_weights(
  dt,
  B,
  rhs_formula,
  fitter,
  modify_C = identity,
  predictor,
  fitter_args = list()
)

bsaul/conservation_spillover documentation built on Feb. 26, 2021, 1:28 p.m.